Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(110)

Unified Diff: components/offline_pages/core/background/request_coordinator_unittest.cc

Issue 2867103006: [Offline pages] Rename REMOVED to USER_CANCELED and add better foot note descriptions for histogram… (Closed)
Patch Set: rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/core/background/request_coordinator_unittest.cc
diff --git a/components/offline_pages/core/background/request_coordinator_unittest.cc b/components/offline_pages/core/background/request_coordinator_unittest.cc
index d75650186fc7b18f18971a84b26fdafe8b53dc72..9291c1841ddc5130d5c00ab40afe2b49646acdc0 100644
--- a/components/offline_pages/core/background/request_coordinator_unittest.cc
+++ b/components/offline_pages/core/background/request_coordinator_unittest.cc
@@ -1105,7 +1105,7 @@ TEST_F(RequestCoordinatorTest, MarkRequestCompleted) {
coordinator()->MarkRequestCompleted(request_id);
PumpLoop();
// Our observer should have seen SUCCESS instead of REMOVED.
EXPECT_EQ(RequestCoordinator::BackgroundSavePageResult::SUCCESS,
observer().last_status());
EXPECT_TRUE(observer().completed_called());
@@ -1359,7 +1359,7 @@ TEST_F(RequestCoordinatorTest, RemoveRequest) {
PumpLoop();
EXPECT_TRUE(observer().completed_called());
- EXPECT_EQ(RequestCoordinator::BackgroundSavePageResult::REMOVED,
+ EXPECT_EQ(RequestCoordinator::BackgroundSavePageResult::USER_CANCELED,
observer().last_status());
EXPECT_EQ(1UL, last_remove_results().size());
EXPECT_EQ(kRequestId1, std::get<0>(last_remove_results().at(0)));
@@ -1105,7 +1105,7 @@ TEST_F(RequestCoordinatorTest, MarkRequestCompleted) {
coordinator()->MarkRequestCompleted(request_id);
PumpLoop();
- // Our observer should have seen SUCCESS instead of REMOVED.
+ // Our observer should have seen SUCCESS instead of USER_CANCELED.
EXPECT_EQ(RequestCoordinator::BackgroundSavePageResult::SUCCESS,
observer().last_status());

Powered by Google App Engine
This is Rietveld 408576698